@@ -3,7 +3,7 @@ package Test01;
 use Moose;
 use MooseX::App qw(Config);
 
-has 'global' => (
+option 'global' => (
     isa             => 'Int',
     is              => 'rw',
     required        => 1,
@@ -11,4 +11,9 @@ has 'global' => (
     cmd_tags        => ['Important!'],
 );
 
+has 'private' => (
+    isa             => 'Int',
+    is              => 'rw',
+);
+
 1;
\ No newline at end of file
